Package: mina
Title: Microbial community dIversity and Network Analysis
Version: 1.20.0
Authors@R: c(person("Rui", "Guan", email = "guan@mpipz.mpg.de", role = c("aut", "cre")),
    person("Ruben", "Garrido-Oter", email = "garridoo@mpipz.mpg.de", role = "ctb"))
Description: An increasing number of microbiome datasets have been generated and analyzed with the help of rapidly developing sequencing technologies. At present, analysis of taxonomic profiling data is mainly conducted using composition-based methods, which ignores interactions between community members. Besides this, a lack of efficient ways to compare microbial interaction networks limited the study of community dynamics. To better understand how community diversity is affected by complex interactions between its members, we developed a framework (Microbial community dIversity and Network Analysis, mina), a comprehensive framework for microbial community diversity analysis and network comparison. By defining and integrating network-derived community features, we greatly reduce noise-to-signal ratio for diversity analyses. A bootstrap and permutation-based method was implemented to assess community network dissimilarities and extract discriminative features in a statistically principled way.
Depends: R (>= 4.0.0)
LinkingTo: Rcpp, RcppParallel, RcppArmadillo
License: GPL
Encoding: UTF-8
Imports: methods, stats, Rcpp, MCL, RSpectra, apcluster, bigmemory,
        foreach, ggplot2, parallel, parallelDist, reshape2, plyr,
        biganalytics, stringr, Hmisc, utils
LazyData: true
Suggests: knitr, rmarkdown
Enhances: doMC
VignetteBuilder: knitr
RoxygenNote: 7.1.1
Collate: 'RcppChk.R' 'RcppExports.R' 'all_classes.R' 'all_generics.R'
        'adj.R' 'all_accessors.R' 'bs_pm.R' 'check.R' 'com_dis.R'
        'com_plot.R' 'com_r2.R' 'data.R' 'dmr.R' 'fit_tabs.R'
        'get_rep.R' 'net_cls.R' 'net_cls_tab.R' 'net_dis.R'
        'net_dis_indi.R' 'net_dis_pcoa.R' 'net_dis_plot.R'
        'net_grp_cmp.R' 'net_node_cmp.R' 'norm_tab.R'
biocViews: Software, WorkflowStep
BugReports: https://github.com/Guan06/mina
git_url: https://git.bioconductor.org/packages/mina
git_branch: RELEASE_3_23
git_last_commit: 757644d
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: yes
Packaged: 2026-04-28 22:49:59 UTC; biocbuild
Author: Rui Guan [aut, cre],
  Ruben Garrido-Oter [ctb]
Maintainer: Rui Guan <guan@mpipz.mpg.de>
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-29 04:50:36 UTC; unix
