# Generated by roxygen2: do not edit by hand

export("des<-")
export("dis<-")
export("norm<-")
export("tab<-")
export(adj)
export(adj_method_list)
export(bs_pm)
export(check_mina)
export(check_mina_de)
export(check_mina_qu)
export(cls_tab)
export(com_dis)
export(com_dis_list)
export(com_plot)
export(com_r2)
export(cp_cor)
export(des)
export(dis)
export(dis_bs)
export(dis_pm)
export(dis_stat)
export(dmr)
export(fit_tabs)
export(get_r2)
export(get_rep)
export(net_cls)
export(net_cls_tab)
export(net_dis)
export(net_dis_indi)
export(net_dis_pcoa)
export(net_dis_plot)
export(net_grp_cmp)
export(net_node_cmp)
export(norm)
export(norm_tab)
export(norm_tab_method_list)
export(pcoa_plot)
export(tab)
export(tina)
exportClasses(mina)
exportMethods("des<-")
exportMethods("dis<-")
exportMethods("norm<-")
exportMethods("tab<-")
exportMethods(.dmr)
exportMethods(adj)
exportMethods(bs_pm)
exportMethods(com_dis)
exportMethods(com_plot)
exportMethods(com_r2)
exportMethods(des)
exportMethods(dis)
exportMethods(dmr)
exportMethods(fit_tabs)
exportMethods(get_net_cls_tab)
exportMethods(get_r2)
exportMethods(get_rep)
exportMethods(net_cls)
exportMethods(net_cls_tab)
exportMethods(net_dis)
exportMethods(net_dis_indi)
exportMethods(net_dis_pcoa)
exportMethods(net_dis_plot)
exportMethods(net_grp_cmp)
exportMethods(net_node_cmp)
exportMethods(norm)
exportMethods(norm_tab)
exportMethods(pcoa_plot)
exportMethods(tab)
exportMethods(tina)
import(ggplot2)
import(stringr)
importFrom(Hmisc,rcorr)
importFrom(MCL,mcl)
importFrom(RSpectra,eigs_sym)
importFrom(Rcpp,sourceCpp)
importFrom(apcluster,apcluster)
importFrom(biganalytics,colsum)
importFrom(bigmemory,attach.big.matrix)
importFrom(bigmemory,big.matrix)
importFrom(bigmemory,describe)
importFrom(foreach,"%dopar%")
importFrom(foreach,foreach)
importFrom(methods,as)
importFrom(methods,new)
importFrom(methods,setClass)
importFrom(methods,setGeneric)
importFrom(methods,setMethod)
importFrom(methods,setRefClass)
importFrom(parallel,mclapply)
importFrom(parallelDist,parDist)
importFrom(plyr,alply)
importFrom(reshape2,melt)
importFrom(stats,cmdscale)
importFrom(stats,dist)
importFrom(stats,sd)
importFrom(stringr,str_detect)
importFrom(utils,combn)
importFrom(utils,write.table)
useDynLib(mina, .registration = TRUE)
