% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\name{maize_asv}
\alias{maize_asv}
\title{ASV table of maize project, vegetative stage samples only.}
\format{
A matrix with samples in columns and ASVs in rows. Unormalized table
including 12765 ASVs from 420 samples.
}
\source{
RECONSTRUCT project, maize microbiome part.
}
\description{
ASV table of maize project, vegetative stage samples only.
}
\examples{
data(maize_asv)

}
