% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\name{hmp_des}
\alias{hmp_des}
\title{Design file for HMP project, including 2711 samples in total.}
\format{
A data frame with columns:
\describe{
 \item{Sample_ID}{The unique ID of the microbial profiling sample.}
 \item{Sex}{The gender of the host human.}
 \item{Run_center}{The lab proccessing the sample sequencing.}
 \item{Subsite}{The subsite of body where samples were collected.}
 \item{Site}{The site of body where samples were collectec.}
 \item{Description}{The further details about the samples.}
}
}
\source{
HMP project.
}
\description{
Design file for HMP project, including 2711 samples in total.
}
\examples{
data(hmp_des)

}
