% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\name{hmp_otu}
\alias{hmp_otu}
\title{OTU table of HMP project, data downloaded from
https://www.hmpdacc.org/hmp/HMQCP/}
\format{
A matrix with samples in columns and OTUs in rows.
}
\source{
HMP project.
}
\description{
OTU table of HMP project, data downloaded from
https://www.hmpdacc.org/hmp/HMQCP/
}
\examples{
data(hmp_otu)

}
