% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fit_tabs.R
\name{fit_tabs,mina-method}
\alias{fit_tabs,mina-method}
\title{Filter the quantitative and descriptive table to make them have the same
samples, samples present in both tables are remained. If `norm` table exist in
the `mina` object, descriptive table will be filtered again to only keep
samples present in `norm`.}
\usage{
\S4method{fit_tabs}{mina}(x)
}
\arguments{
\item{x}{An object of class mina.}
}
\value{
x The same object as input with fitted `tab`, `des` and `norm` (if
defined).
}
\description{
Filter the quantitative and descriptive table to make them have the same
samples, samples present in both tables are remained. If `norm` table exist in
the `mina` object, descriptive table will be filtered again to only keep
samples present in `norm`.
}
\examples{
{
data(maize)
maize <- fit_tabs(maize)
maize <- norm_tab(maize, method = "total")
maize <- fit_tabs(maize)
}
}
