% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\name{maize_asv2}
\alias{maize_asv2}
\title{Subset of ASV table of maize project, ASVs appear in less than 100 samples
were filtered for later analysis.}
\format{
A matrix with samples in columns and ASVs in rows. Unormalized table
including 1219 ASVs from 313 samples.
}
\source{
RECONSTRUCT project, maize microbiome part.
}
\description{
Subset of ASV table of maize project, ASVs appear in less than 100 samples
were filtered for later analysis.
}
\examples{
data(maize_asv2)

}
