% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/net_cls.R
\name{re_format_MCL}
\alias{re_format_MCL}
\title{Convert mcl (mcl output) to dataframe.}
\usage{
re_format_MCL(x, names)
}
\arguments{
\item{x}{an `mcl` object from \code{\link[MCL]{mcl}}.}

\item{names}{The names of clustered components.}
}
\value{
y A data frame with columns `ID`, `Cluster` and `Cluster_size`.
}
\description{
Modified from https://rdrr.io/github/jefferis/flycircuit/src/R/clustering.R
#sym-as.data.frame.APResult
}
\seealso{
\code{\link[MCL]{mcl}}
}
\keyword{internal}
